pub enum PackError {
ConstraintsFailed(String),
MaxIterations,
NoTargets,
EmptyMolecule(usize),
InvalidPBCBox {
min: [F; 3],
max: [F; 3],
},
ConflictingPeriodicBoxes {
first: ([F; 3], [F; 3], [bool; 3]),
second: ([F; 3], [F; 3], [bool; 3]),
},
}Variants
ConstraintsFailed(String)
Molecules could not satisfy constraints even without distance tolerances.
MaxIterations
Maximum iterations reached without convergence.
NoTargets
No molecules were provided.
EmptyMolecule(usize)
A molecule has no atoms.
InvalidPBCBox
A restraint declared a periodic box whose max - min is
non-positive on at least one axis.
ConflictingPeriodicBoxes
Two or more restraints declared periodic boxes with different bounds or different per-axis periodicity flags. Only one periodic box is allowed per packing run.