pub enum RestraintSpec {
InsideBox {
min: [f64; 3],
max: [f64; 3],
},
InsideSphere {
center: [f64; 3],
radius: f64,
},
OutsideSphere {
center: [f64; 3],
radius: f64,
},
AbovePlane {
normal: [f64; 3],
distance: f64,
},
BelowPlane {
normal: [f64; 3],
distance: f64,
},
InsideCube {
origin: [f64; 3],
side: f64,
},
OutsideCube {
origin: [f64; 3],
side: f64,
},
OutsideBox {
min: [f64; 3],
max: [f64; 3],
},
InsideEllipsoid {
center: [f64; 3],
axes: [f64; 3],
exponent: f64,
},
OutsideEllipsoid {
center: [f64; 3],
axes: [f64; 3],
exponent: f64,
},
InsideCylinder {
center: [f64; 3],
axis: [f64; 3],
radius: f64,
length: f64,
},
OutsideCylinder {
center: [f64; 3],
axis: [f64; 3],
radius: f64,
length: f64,
},
}Expand description
AtomRestraint as it appears in the script, before being mapped to a
concrete AtomRestraint implementation.
Variants
InsideBox
InsideSphere
OutsideSphere
AbovePlane
over plane — atom must lie above the plane.
BelowPlane
below plane — atom must lie below the plane.
InsideCube
inside cube x0 y0 z0 d — atom inside an axis-aligned cube.
OutsideCube
outside cube x0 y0 z0 d — atom outside an axis-aligned cube.
OutsideBox
outside box xmin ymin zmin xmax ymax zmax — atom outside a box.
InsideEllipsoid
inside ellipsoid a1 a2 a3 b1 b2 b3 c — center, semi-axes, exponent.
OutsideEllipsoid
outside ellipsoid a1 a2 a3 b1 b2 b3 c — center, semi-axes, exponent.
InsideCylinder
inside cylinder a1 a2 a3 d1 d2 d3 r l — center, axis, radius, length.
OutsideCylinder
outside cylinder a1 a2 a3 d1 d2 d3 r l — center, axis, radius, length.